@@ -5,6 +5,8 @@ use php_literal_parser::Value;
 #[cfg(feature = "redis-connect")]
 use redis::{ConnectionAddr, ConnectionInfo};
 use std::collections::HashMap;
+use std::fs::DirEntry;
+use std::iter::once;
 use std::net::IpAddr;
 use std::path::{Path, PathBuf};
 use std::str::FromStr;
@@ -16,22 +18,25 @@ static CONFIG_CONSTANTS: &[(&str, &str)] = &[
     (r"\RedisCluster::FAILOVER_DISTRIBUTE_SLAVES", "3"),
 ];
 
-fn glob_config_files(path: impl AsRef<Path>) -> Vec<PathBuf> {
-    let mut configs = vec![path.as_ref().into()];
-    if let Some(parent) = path.as_ref().parent() {
+fn glob_config_files(path: impl AsRef<Path>) -> impl Iterator<Item = PathBuf> {
+    let main: PathBuf = path.as_ref().into();
+    let files = if let Some(parent) = path.as_ref().parent() {
         if let Ok(dir) = parent.read_dir() {
-            for file in dir.filter_map(Result::ok) {
+            Some(dir.filter_map(Result::ok).filter_map(|file: DirEntry| {
                 let path = file.path();
                 match path.to_str() {
-                    Some(path_str) if path_str.ends_with(".config.php") => {
-                        configs.push(path);
-                    }
-                    _ => {}
+                    Some(path_str) if path_str.ends_with(".config.php") => Some(path),
+                    _ => None,
                 }
-            }
+            }))
+        } else {
+            None
         }
-    }
-    configs
+    } else {
+        None
+    };
+
+    once(main).chain(files.into_iter().flatten())
 }
 
 fn parse_php(path: impl AsRef<Path>) -> Result<Value> {
@@ -82,7 +87,7 @@ fn merge_configs(input: Vec<(PathBuf, Value)>) -> Result<Value> {
     Ok(Value::Array(merged))
 }
 
-fn parse_files(files: Vec<PathBuf>) -> Result<Config> {
+fn parse_files(files: impl IntoIterator<Item = PathBuf>) -> Result<Config> {
     let parsed_files = files
         .into_iter()
         .map(|path| {
@@ -114,7 +119,7 @@ fn parse_files(files: Vec<PathBuf>) -> Result<Config> {
 }
 
 pub fn parse(path: impl AsRef<Path>) -> Result<Config> {
-    parse_files(glob_config_files(path))
+    parse_files(once(path.as_ref().into()))
 }
 
 pub fn parse_glob(path: impl AsRef<Path>) -> Result<Config> {
@@ -584,6 +589,29 @@ fn test_parse_config_multiple() {
     );
 }
 
+#[test]
+fn test_parse_config_multiple_no_glob() {
+    let config = config_from_file("tests/configs/multiple/config.php");
+    assert_eq!("https://cloud.example.com", config.nextcloud_url);
+    assert_eq!("oc_", config.database_prefix);
+    assert_debug_equal(
+        &Database::Sqlite {
+            database: "/nc/nextcloud.db".into(),
+        },
+        &config.database,
+    );
+    #[cfg(feature = "db-sqlx")]
+    assert_debug_equal(
+        AnyConnectOptions::from_str("sqlite:///nc/nextcloud.db").unwrap(),
+        config.database.into(),
+    );
+    #[cfg(feature = "redis-connect")]
+    assert_debug_equal(
+        RedisConfig::Single(ConnectionInfo::from_str("redis://127.0.0.1").unwrap()),
+        config.redis,
+    );
+}
+
 #[test]
 fn test_parse_config_mysql_fqdn() {
     let config = config_from_file("tests/configs/mysql_fqdn.php");
